#!/usr/bin/perl
# --
# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
# --
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU AFFERO General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
# or see http://www.gnu.org/licenses/agpl.txt.
# --

use strict;
use warnings;

use File::Basename;
use FindBin qw($RealBin);
use lib dirname($RealBin);
use lib dirname($RealBin) . '/Kernel/cpan-lib';
use lib dirname($RealBin) . '/Custom';

use Kernel::System::ObjectManager;

local $Kernel::OM = Kernel::System::ObjectManager->new(
    'Kernel::System::Log' => {
        LogPrefix => 'OTRS-otrs.LinkCI.pl',
    },
);

my $LogObject = $Kernel::OM->Get('Kernel::System::Log');
my $LinkObject = $Kernel::OM->Get('Kernel::System::LinkObject');
my $ConfigItemObject = $Kernel::OM->Get('Kernel::System::ITSMConfigItem');


my $FileName = $ARGV[0];
if( !$FileName || ! -f $FileName){
        print "Usage: LinkCIs.pl file.csv\n";
        print "csv format: id,name hw,name sw\n";
        exit (1);
}

open FILE, $FileName or die $!;
while (<FILE>) {
	chomp($_);
	my @FIELDS = split ",", $_;
	 $LogObject->Log(
	            Priority => 'notice',
        	    Message  => "HW:$FIELDS[1]|SW:$FIELDS[2]|",
	);
	my $HW = $ConfigItemObject->ConfigItemSearchExtended(
		Name => $FIELDS[1],
	);
	my $SW = $ConfigItemObject->ConfigItemSearchExtended(
		Name => $FIELDS[2],
	);

	if( $HW && ref $HW eq 'ARRAY' && @{$HW} && $SW && ref $SW  eq 'ARRAY' && @{$SW}) {
		my $LinkResult = $LinkObject->LinkAdd(
			SourceObject => 'ITSMConfigItem',
			SourceKey => @{$SW}[0],
			TargetObject => 'ITSMConfigItem',
			TargetKey => @{$HW}[0],
			Type => 'RelevantTo',
			State => 'Valid',
			UserID => 1,
		);
	}
}
close FILE;


